Enum diem_types::transaction::Transaction [−][src]
pub enum Transaction {
UserTransaction(SignedTransaction),
GenesisTransaction(WriteSetPayload),
BlockMetadata(BlockMetadata),
StateCheckpoint,
}Expand description
Transaction will be the transaction type used internally in the diem node to represent the
transaction to be processed and persisted.
We suppress the clippy warning here as we would expect most of the transaction to be user transaction.
Variants
UserTransaction(SignedTransaction)Transaction submitted by the user. e.g: P2P payment transaction, publishing module transaction, etc. TODO: We need to rename SignedTransaction to SignedUserTransaction, as well as all the other transaction types we had in our codebase.
Tuple Fields of UserTransaction
GenesisTransaction(WriteSetPayload)Transaction that applies a WriteSet to the current storage, it’s applied manually via db-bootstrapper.
Tuple Fields of GenesisTransaction
BlockMetadata(BlockMetadata)Transaction to update the block metadata resource at the beginning of a block.
Tuple Fields of BlockMetadata
Transaction to let the executor update the global state tree and record the root hash in the TransactionInfo
Implementations