Enum diem_types::transaction::TransactionPayload [−][src]
pub enum TransactionPayload {
WriteSet(WriteSetPayload),
Script(Script),
ModuleBundle(ModuleBundle),
ScriptFunction(ScriptFunction),
}Expand description
Different kinds of transactions.
Variants
WriteSet(WriteSetPayload)A system maintenance transaction.
Tuple Fields of WriteSet
Script(Script)A transaction that executes code.
Tuple Fields of Script
0: ScriptModuleBundle(ModuleBundle)A transaction that publishes multiple modules at the same time.
Tuple Fields of ModuleBundle
0: ModuleBundleScriptFunction(ScriptFunction)A transaction that executes an existing script function published on-chain.
Tuple Fields of ScriptFunction
Implementations
Similar to write_set_strategy except generates a valid write set for the genesis block.