Enum diem_types::transaction::TransactionStatus [−][src]
pub enum TransactionStatus {
Discard(DiscardedVMStatus),
Keep(KeptVMStatus),
Retry,
}Expand description
The status of executing a transaction. The VM decides whether or not we should Keep the
transaction output or Discard it based upon the execution of the transaction. We wrap these
decisions around a VMStatus that provides more detail on the final execution state of the VM.
Variants
Discard(DiscardedVMStatus)Discard the transaction output
Tuple Fields of Discard
Keep(KeptVMStatus)Keep the transaction output
Tuple Fields of Keep
0: KeptVMStatusRetry the transaction, e.g., after a reconfiguration
Implementations