Struct diem_types::transaction::AccountTransactionsWithProof [−][src]
pub struct AccountTransactionsWithProof(pub Vec<TransactionWithProof>);Expand description
A list of transactions under an account that are contiguous by sequence number and include proofs.
Tuple Fields
0: Vec<TransactionWithProof>Implementations
pub fn verify(
&self,
ledger_info: &LedgerInfo,
account: AccountAddress,
start_seq_num: u64,
limit: u64,
include_events: bool,
ledger_version: Version
) -> Result<()>
pub fn verify(
&self,
ledger_info: &LedgerInfo,
account: AccountAddress,
start_seq_num: u64,
limit: u64,
include_events: bool,
ledger_version: Version
) -> Result<()>
- Verify all transactions are consistent with the given ledger info.
- All transactions were sent by
account. - The transactions are contiguous by sequence number, starting at
start_seq_num. - No more transactions than limit.
- Events are present when requested (and not present when not requested).
- Transactions are not newer than requested ledger version.