Struct diem_types::transaction::TransactionWithProof [−][src]
pub struct TransactionWithProof {
pub version: Version,
pub transaction: Transaction,
pub events: Option<Vec<ContractEvent>>,
pub proof: TransactionInfoWithProof,
}Fields
version: Versiontransaction: Transactionevents: Option<Vec<ContractEvent>>proof: TransactionInfoWithProofImplementations
pub fn new(
version: Version,
transaction: Transaction,
events: Option<Vec<ContractEvent>>,
proof: TransactionInfoWithProof
) -> Self
pub fn verify_user_txn(
&self,
ledger_info: &LedgerInfo,
version: Version,
sender: AccountAddress,
sequence_number: u64
) -> Result<()>
pub fn verify_user_txn(
&self,
ledger_info: &LedgerInfo,
version: Version,
sender: AccountAddress,
sequence_number: u64
) -> Result<()>
Verifies the transaction with the proof, both carried by self.
A few things are ensured if no error is raised:
- This transaction exists in the ledger represented by
ledger_info. - This transaction is a
UserTransaction. - And this user transaction has the same
version,sender, andsequence_numberas indicated by the parameter list. If any of these parameter is unknown to the call site that is supposed to be informed via this struct, get it from the struct itself, such as version and sender.