Enum diem_types::transaction::TransactionInfo [−][src]
pub enum TransactionInfo {
V0(TransactionInfoV0),
}Expand description
TransactionInfo is the object we store in the transaction accumulator. It consists of the
transaction as well as the execution result of this transaction.
Variants
Tuple Fields of V0
Implementations
Methods from Deref<Target = TransactionInfoV0>